"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk import utils
from skylight_sdk.types import BaseModel


class WindowsModelsErrorResponseData(BaseModel):
    detail: str
    r"""Error message describing what went wrong"""


class WindowsModelsErrorResponse(Exception):
    r"""Standard error response containing details about the error"""

    data: WindowsModelsErrorResponseData

    def __init__(self, data: WindowsModelsErrorResponseData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, WindowsModelsErrorResponseData)
