"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .clickrequest import ClickRequest, ClickRequestTypedDict
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ClickRequest1TypedDict(TypedDict):
    instance_id: str
    click_request: ClickRequestTypedDict


class ClickRequest1(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    click_request: Annotated[
        ClickRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
