"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .instancestatusresponse import (
    InstanceStatusResponse,
    InstanceStatusResponseTypedDict,
)
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InstancesListResponseTypedDict(TypedDict):
    instances: List[InstanceStatusResponseTypedDict]
    r"""List of instances associated with the API key"""


class InstancesListResponse(BaseModel):
    instances: List[InstanceStatusResponse]
    r"""List of instances associated with the API key"""
