"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .keyrequest import KeyRequest, KeyRequestTypedDict
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class KeypressRequestTypedDict(TypedDict):
    instance_id: str
    key_request: KeyRequestTypedDict


class KeypressRequest(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    key_request: Annotated[
        KeyRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
