"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from skylight_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List
from typing_extensions import NotRequired, TypedDict


class AgentStatusResponseFilesTypedDict(TypedDict):
    pass


class AgentStatusResponseFiles(BaseModel):
    pass


class HumanInputRequestTypedDict(TypedDict):
    pass


class HumanInputRequest(BaseModel):
    pass


class AgentStatusResponseTypedDict(TypedDict):
    agent_status: str
    r"""Current status of the agent"""
    is_running: bool
    r"""Whether the agent is currently running"""
    total_steps: int
    r"""Total number of steps executed"""
    files: List[AgentStatusResponseFilesTypedDict]
    r"""List of files downloaded by the agent"""
    messages: List[str]
    r"""List of steps executed by the agent"""
    created_at: str
    r"""Timestamp when the agent was created"""
    query: str
    r"""Original query given to the agent"""
    agent_id: str
    r"""Unique identifier for the agent"""
    final_summary: NotRequired[Nullable[str]]
    r"""Final summary of agent execution"""
    human_input_request: NotRequired[Nullable[HumanInputRequestTypedDict]]
    r"""Information about the human input being requested, if agent is waiting"""


class AgentStatusResponse(BaseModel):
    agent_status: str
    r"""Current status of the agent"""

    is_running: bool
    r"""Whether the agent is currently running"""

    total_steps: int
    r"""Total number of steps executed"""

    files: List[AgentStatusResponseFiles]
    r"""List of files downloaded by the agent"""

    messages: List[str]
    r"""List of steps executed by the agent"""

    created_at: str
    r"""Timestamp when the agent was created"""

    query: str
    r"""Original query given to the agent"""

    agent_id: str
    r"""Unique identifier for the agent"""

    final_summary: OptionalNullable[str] = UNSET
    r"""Final summary of agent execution"""

    human_input_request: OptionalNullable[HumanInputRequest] = UNSET
    r"""Information about the human input being requested, if agent is waiting"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["final_summary", "human_input_request"]
        nullable_fields = ["final_summary", "human_input_request"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
