"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class KeyRequestTypedDict(TypedDict):
    keys: List[str]


class KeyRequest(BaseModel):
    keys: List[str]
