"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class StandardResponseTypedDict(TypedDict):
    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""


class StandardResponse(BaseModel):
    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""
