"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class FileDownloadResponseTypedDict(TypedDict):
    r"""Response containing a presigned URL to download a file"""

    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""
    download_url: str
    r"""Presigned URL to download the file"""


class FileDownloadResponse(BaseModel):
    r"""Response containing a presigned URL to download a file"""

    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""

    download_url: str
    r"""Presigned URL to download the file"""
