"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AnswerResponseTypedDict(TypedDict):
    pass


class AnswerResponse(BaseModel):
    pass


class AnswerRequestTypedDict(TypedDict):
    agent_id: str
    request_body: AnswerResponseTypedDict


class AnswerRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        AnswerResponse,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
