"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class FileUploadResponseTypedDict(TypedDict):
    r"""Response when a file is successfully uploaded to a VM"""

    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""
    file_path: str
    r"""Path where the file was saved on the VM"""


class FileUploadResponse(BaseModel):
    r"""Response when a file is successfully uploaded to a VM"""

    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""

    file_path: str
    r"""Path where the file was saved on the VM"""
