"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class MouseMoveRequestTypedDict(TypedDict):
    x: int
    y: int


class MouseMoveRequest(BaseModel):
    x: int

    y: int
