"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class InstanceStartResponseTypedDict(TypedDict):
    instance_id: str
    r"""Unique identifier of the created instance"""
    message: str
    r"""Human-readable status message"""
    livestream_url: str
    r"""URL to livestream the instance"""
    state: str
    r"""State of the instance (running, pending, hibernated, terminated)"""


class InstanceStartResponse(BaseModel):
    instance_id: str
    r"""Unique identifier of the created instance"""

    message: str
    r"""Human-readable status message"""

    livestream_url: str
    r"""URL to livestream the instance"""

    state: str
    r"""State of the instance (running, pending, hibernated, terminated)"""
