"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class ScreenshotResponseTypedDict(TypedDict):
    image: str
    r"""Base64-encoded JPEG image of the instance screenshot"""


class ScreenshotResponse(BaseModel):
    image: str
    r"""Base64-encoded JPEG image of the instance screenshot"""
