"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict
from typing_extensions import Annotated, TypedDict


class DownloadRequestTypedDict(TypedDict):
    instance_id: str
    request_body: Dict[str, str]


class DownloadRequest(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Dict[str, str],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
