"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PackageInstallRequestTypedDict(TypedDict):
    packages: List[str]
    r"""List of Chocolatey package names to install"""


class PackageInstallRequest(BaseModel):
    packages: List[str]
    r"""List of Chocolatey package names to install"""
